##  Discovery Suggestions for AI Agents
In the discovery inbox, you get recommendations for linking discovered AI agents to applications, IT components, and providers. Additionally, you get suggestions for linking AI agents to business capabilities.
### Discovered Fact Sheets
Fact Sheet Type | Description | Example | Action Available
---|---|---|---
AI agent (subtype of application) | Agents that perform business tasks or deliver outcomes, such as automating workflows or interacting with users. |
  * SAP Joule Accounts Receivable Agent
  * Microsoft Entra ID Access Review Agent

| Create or link
IT component | Technology elements such as operating systems, databases, runtimes, or platforms that help agents run or connect with other systems. |
  * Google Agent Engine
  * SAP Joule
  * Azure AI Foundry

| Create or link
Provider | Companies or entities associated with IT components. |
  * SAP (Joule)
  * Microsoft (Entra ID)
  * Google (Vertex AI).

| Create or link


### Additional Suggestions
Fact Sheet Type | Description | Example | Action Available
---|---|---|---
Business capability | Functional areas of the organization that agents support.  |
  * Financial Planning
  * Customer Experience Management

| Link


